# incentive utils
Data collectors from energy data sources

## Installation

Run the following to install 
```
python -m pip install git+https://github.com/tfranch/datacollectors.git#egg=datacollectors
```

## Usage

```
import datacollectors

# connectors: Entsoe, ECB and ICE
```


